@@ -397,7 +397,7 @@ nautilus_icon_info_lookup (GIcon *icon,
 
 		filename = gtk_icon_info_get_filename (gtkicon_info);
 		if (filename == NULL) {
-			gtk_icon_info_free (gtkicon_info);
+			g_object_unref (gtkicon_info);
 			return nautilus_icon_info_new_for_pixbuf (NULL);
 		}
 
@@ -406,7 +406,7 @@ nautilus_icon_info_lookup (GIcon *icon,
 
 		icon_info = g_hash_table_lookup (themed_icon_cache, &lookup_key);
 		if (icon_info) {
-			gtk_icon_info_free (gtkicon_info);
+			g_object_unref (gtkicon_info);
 			return g_object_ref (icon_info);
 		}
 		
@@ -415,7 +415,7 @@ nautilus_icon_info_lookup (GIcon *icon,
 		key = themed_icon_key_new (filename, size);
 		g_hash_table_insert (themed_icon_cache, key, icon_info);
 
-		gtk_icon_info_free (gtkicon_info);
+		g_object_unref (gtkicon_info);
 
 		return g_object_ref (icon_info);
 	} else {
@@ -428,7 +428,7 @@ nautilus_icon_info_lookup (GIcon *icon,
                                                                 GTK_ICON_LOOKUP_GENERIC_FALLBACK);
                 if (gtk_icon_info != NULL) {
                         pixbuf = gtk_icon_info_load_icon (gtk_icon_info, NULL);
-                        gtk_icon_info_free (gtk_icon_info);
+                        g_object_unref (gtk_icon_info);
                 } else {
                         pixbuf = NULL;
                 }
