@@ -168,7 +168,7 @@ on_uri_entry_clear (GtkEntry                    *entry,
 }
 
 static const char *
-get_default_scheme (NautilusConnectServerDialog *dialog)
+get_default_schema (NautilusConnectServerDialog *dialog)
 {
 	if (dialog->details->supported == NULL) {
 		return NULL;
@@ -256,11 +256,17 @@ reset_example_label (NautilusConnectServerDialog *dialog)
 {
 	char *text;
 	char *uri;
+	const char *schema;
 
-	uri = g_strdup_printf ("%s://foo.example.com", get_default_scheme (dialog));
-	/* Translators: %s is a URI of the form "smb://foo.example.com" */
-	text = g_strdup_printf (_("For example, %s"), uri);
-	g_free (uri);
+	schema = get_default_schema (dialog);
+	if (schema != NULL) {
+		uri = g_strdup_printf ("%s://foo.example.org", schema);
+		/* Translators: %s is a URI of the form "smb://foo.example.com" */
+		text = g_strdup_printf (_("For example, %s"), uri);
+		g_free (uri);
+	} else {
+		text = g_strdup ("");
+	}
 	gtk_label_set_text (GTK_LABEL (dialog->details->error_label), text);
 	g_free (text);
 }
@@ -269,34 +275,31 @@ static void
 check_uri_entry (NautilusConnectServerDialog *dialog)
 {
 	guint length;
-	gboolean active = FALSE;
+	gboolean button_active = FALSE;
+	gboolean icon_active = FALSE;
 	const char *text = NULL;
-	const char *icon_name = NULL;
 
 	length = gtk_entry_get_text_length (GTK_ENTRY (dialog->details->uri_entry));
 	if (length > 0) {
 		GError *error = NULL;
 
 		text = gtk_entry_get_text (GTK_ENTRY (dialog->details->uri_entry));
-		active = validate_uri (dialog, text, &error);
+		button_active = validate_uri (dialog, text, &error);
 		if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED)) {
 			gtk_label_set_text (GTK_LABEL (dialog->details->error_label), error->message);
 		} else {
 			reset_example_label (dialog);
 		}
 		g_clear_error (&error);
+		icon_active = TRUE;
 	}
 
-	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_OK, active);
-
-	if (length > 0) {
-		icon_name = "edit-clear-symbolic";
-	}
+	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_OK, button_active);
 
 	g_object_set (dialog->details->uri_entry,
-		      "secondary-icon-name", icon_name,
-		      "secondary-icon-activatable", active,
-		      "secondary-icon-sensitive", active,
+		      "secondary-icon-name", icon_active ? "edit-clear-symbolic" : NULL,
+		      "secondary-icon-activatable", icon_active,
+		      "secondary-icon-sensitive", icon_active,
 		      NULL);
 }
 
