@@ -35,7 +35,6 @@
 #include "nautilus-special-location-bar.h"
 #include "nautilus-toolbar.h"
 #include "nautilus-trash-bar.h"
-#include "nautilus-view-factory.h"
 #include "nautilus-window-private.h"
 #include "nautilus-x-content-bar.h"
 
@@ -526,7 +525,7 @@ nautilus_window_slot_add_extra_location_widget (NautilusWindowSlot *slot,
 						GtkWidget *widget)
 {
 	gtk_box_pack_start (GTK_BOX (slot->details->extra_location_widgets),
-			    widget, TRUE, TRUE, 0);
+			    widget, FALSE, TRUE, 0);
 	gtk_widget_show (slot->details->extra_location_widgets);
 }
 
@@ -1258,15 +1257,6 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 
 		if (view_id == NULL) {
 			view_id = nautilus_global_preferences_get_default_folder_viewer_preference_as_iid ();
-
-			if (view_id != NULL &&
-			    !nautilus_view_factory_view_supports_uri (view_id,
-								      location,
-								      nautilus_file_get_file_type (file),
-								      mimetype)) {
-				g_free (view_id);
-				view_id = NULL;
-			}
 		}
 
 		g_free (mimetype);
@@ -1391,16 +1381,14 @@ create_content_view (NautilusWindowSlot *slot,
 		view_id = NAUTILUS_DESKTOP_ICON_VIEW_IID;
 	}
 
-        if (slot->details->content_view != NULL &&
-	    g_strcmp0 (nautilus_view_get_view_id (slot->details->content_view),
-			view_id) == 0) {
+        if (nautilus_window_slot_content_view_matches_iid (slot, view_id)) {
                 /* reuse existing content view */
                 view = slot->details->content_view;
                 slot->details->new_content_view = view;
 		g_object_ref (view);
         } else {
                 /* create a new content view */
-		view = nautilus_view_factory_create (view_id, slot);
+		view = nautilus_view_new (view_id, slot);
 
                 slot->details->new_content_view = view;
 		nautilus_window_slot_connect_new_content_view (slot);
