@@ -38,16 +38,16 @@
 #include "nautilus-location-entry.h"
 #include "nautilus-mime-actions.h"
 #include "nautilus-notebook.h"
-#include "nautilus-places-sidebar.h"
 #include "nautilus-pathbar.h"
+#include "nautilus-properties-window.h"
 #include "nautilus-toolbar.h"
-#include "nautilus-view-factory.h"
 #include "nautilus-window-slot.h"
 #include "nautilus-list-view.h"
 #include "nautilus-canvas-view.h"
 
 #include <eel/eel-debug.h>
 #include <eel/eel-gtk-extensions.h>
+#include <eel/eel-stock-dialogs.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk/gdkx.h>
 #include <gdk/gdkkeysyms.h>
@@ -56,13 +56,16 @@
 #ifdef HAVE_X11_XF86KEYSYM_H
 #include <X11/XF86keysym.h>
 #endif
+#include <libnautilus-private/nautilus-dnd.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <libnautilus-private/nautilus-file-attributes.h>
+#include <libnautilus-private/nautilus-file-operations.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-metadata.h>
 #include <libnautilus-private/nautilus-profile.h>
 #include <libnautilus-private/nautilus-clipboard.h>
 #include <libnautilus-private/nautilus-signaller.h>
+#include <libnautilus-private/nautilus-trash-monitor.h>
 
 #define DEBUG_FLAG NAUTILUS_DEBUG_WINDOW
 #include <libnautilus-private/nautilus-debug.h>
@@ -524,11 +527,318 @@ setup_side_pane_width (NautilusWindow *window)
 				window->details->side_pane_width);
 }
 
+/* Callback used when the places sidebar changes location; we need to change the displayed folder */
+static void
+places_sidebar_open_location_cb (GtkPlacesSidebar	*sidebar,
+				 GFile			*location,
+				 GtkPlacesOpenFlags	 open_flags,
+				 gpointer		 user_data)
+{
+	NautilusWindow *window = NAUTILUS_WINDOW (user_data);
+	NautilusWindowOpenFlags flags;
+
+	switch (open_flags) {
+	case GTK_PLACES_OPEN_NEW_TAB:
+		flags = NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB;
+		break;
+
+	case GTK_PLACES_OPEN_NEW_WINDOW:
+		flags = NAUTILUS_WINDOW_OPEN_FLAG_NEW_WINDOW;
+		break;
+
+	case GTK_PLACES_OPEN_NORMAL: /* fall-through */
+	default:
+		flags = 0;
+		break;
+	}
+
+	nautilus_window_slot_open_location (window->details->active_slot, location, flags);
+}
+
+/* Callback used when the places sidebar needs us to present an error message */
+static void
+places_sidebar_show_error_message_cb (GtkPlacesSidebar *sidebar,
+				      const char       *primary,
+				      const char       *secondary,
+				      gpointer          user_data)
+{
+	NautilusWindow *window = NAUTILUS_WINDOW (user_data);
+
+	eel_show_error_dialog (primary, secondary, GTK_WINDOW (window));
+}
+
+/* Callback used when the places sidebar needs us to present the Connect to Server dialog */
+static void
+places_sidebar_show_connect_to_server_cb (GtkPlacesSidebar *sidebar,
+					  gpointer          user_data)
+{
+	NautilusWindow *window = NAUTILUS_WINDOW (user_data);
+	NautilusApplication *application = NAUTILUS_APPLICATION (g_application_get_default ());
+	GtkWidget *dialog;
+ 
+	dialog = nautilus_application_connect_server (application, window);
+	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
+}
+
+static GList *
+build_selection_list_from_gfile_list (GList *gfile_list)
+{
+	GList *result;
+	GList *l;
+
+	result = NULL;
+	for (l = gfile_list; l; l = l->next) {
+		GFile *file;
+		NautilusDragSelectionItem *item;
+
+		file = l->data;
+
+		item = nautilus_drag_selection_item_new ();
+		item->uri = g_file_get_uri (file);
+		item->got_icon_position = FALSE;
+		result = g_list_prepend (result, item);
+	}
+
+	return g_list_reverse (result);
+}
+
+/* Callback used when the places sidebar needs to know the drag action to suggest */
+static GdkDragAction
+places_sidebar_drag_action_requested_cb (GtkPlacesSidebar *sidebar,
+					 GdkDragContext   *context,
+					 GFile            *dest_file,
+					 GList            *source_file_list,
+					 gpointer          user_data)
+{
+	GList *items;
+	char *uri;
+	int action = 0;
+
+	items = build_selection_list_from_gfile_list (source_file_list);
+	uri = g_file_get_uri (dest_file);
+
+	nautilus_drag_default_drop_action_for_icons (context, uri, items, &action);
+
+	nautilus_drag_destroy_selection_list (items);
+	g_free (uri);
+
+	return action;
+}
+
+/* Callback used when the places sidebar needs us to pop up a menu with possible drag actions */
+static GdkDragAction
+places_sidebar_drag_action_ask_cb (GtkPlacesSidebar *sidebar,
+				   GdkDragAction     actions,
+				   gpointer          user_data)
+{
+	return nautilus_drag_drop_action_ask (GTK_WIDGET (sidebar), actions);
+}
+
+static GList *
+build_uri_list_from_gfile_list (GList *file_list)
+{
+	GList *result;
+	GList *l;
+
+	result = NULL;
+
+	for (l = file_list; l; l = l->next) {
+		GFile *file = l->data;
+		char *uri;
+
+		uri = g_file_get_uri (file);
+		result = g_list_prepend (result, uri);
+	}
+
+	return g_list_reverse (result);
+	
+}
+
+/* Callback used when the places sidebar has URIs dropped into it.  We do a normal file operation for them. */
+static void
+places_sidebar_drag_perform_drop_cb (GtkPlacesSidebar *sidebar,
+				     GFile            *dest_file,
+				     GList            *source_file_list,
+				     GdkDragAction     action,
+				     gpointer          user_data)
+{
+	char *dest_uri;
+	GList *source_uri_list;
+
+	dest_uri = g_file_get_uri (dest_file);
+	source_uri_list = build_uri_list_from_gfile_list (source_file_list);
+
+	nautilus_file_operations_copy_move (source_uri_list, NULL, dest_uri, action, GTK_WIDGET (sidebar), NULL, NULL);
+
+	g_free (dest_uri);
+	g_list_free_full (source_uri_list, g_free);
+}
+
+/* Callback for our own loading_uri signal.  We update the sidebar's path. */
+static void
+window_loading_uri_cb (NautilusWindow *window,
+		       char           *location,
+		       gpointer        user_data)
+{
+	if (window->details->places_sidebar) {
+		GFile *file;
+
+		file = g_file_new_for_uri (location);
+		gtk_places_sidebar_set_location (GTK_PLACES_SIDEBAR (window->details->places_sidebar), file);
+		g_object_unref (file);
+	}
+}
+
+/* Callback used in the "empty trash" menu item from the places sidebar */
+static void
+empty_trash_cb (GtkMenuItem *item,
+		gpointer     user_data)
+{
+	NautilusWindow *window = NAUTILUS_WINDOW (user_data);
+
+	nautilus_file_operations_empty_trash (GTK_WIDGET (window));
+}
+
+/* Callback used for the "properties" menu item from the places sidebar */
+static void
+properties_cb (GtkMenuItem *item,
+	       gpointer     user_data)
+{
+	NautilusWindow *window = NAUTILUS_WINDOW (user_data);
+	GFile *selected;
+	GList *list;
+	NautilusFile *file;
+
+	selected = gtk_places_sidebar_get_location (GTK_PLACES_SIDEBAR (window->details->places_sidebar));
+	file = nautilus_file_get (selected);
+	g_object_unref (selected);
+
+	list = g_list_append (NULL, file);
+	nautilus_properties_window_present (list, GTK_WIDGET (window), NULL);
+	nautilus_file_list_free (list);
+}
+
+static gboolean
+check_have_gnome_disks (void)
+{
+	gchar *disks_path;
+	gboolean res;
+
+	disks_path = g_find_program_in_path ("gnome-disks");
+	res = (disks_path != NULL);
+	g_free (disks_path);
+
+	return res;
+}
+
+static gboolean
+should_show_format_command (GVolume *volume)
+{
+	gchar *unix_device_id;
+	gboolean show_format;
+
+	unix_device_id = g_volume_get_identifier (volume, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
+	show_format = (unix_device_id != NULL) && check_have_gnome_disks ();
+	g_free (unix_device_id);
+
+	return show_format;
+}
+
+static void
+format_cb (GtkMenuItem *item,
+	   gpointer     user_data)
+{
+	NautilusWindow *window = NAUTILUS_WINDOW (user_data);
+	GAppInfo *app_info;
+	gchar *cmdline, *device_identifier, *xid_string;
+	GVolume *volume;
+	gint xid;
+
+	volume = g_object_get_data (G_OBJECT (item), "nautilus-volume");
+
+	g_assert (volume != NULL && G_IS_VOLUME (volume));
+
+	device_identifier = g_volume_get_identifier (volume, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
+	xid = (gint) gdk_x11_window_get_xid (gtk_widget_get_window (GTK_WIDGET (window)));
+	xid_string = g_strdup_printf ("%d", xid);
+
+	cmdline = g_strconcat ("gnome-disks ",
+			       "--block-device ", device_identifier, " ",
+			       "--format-device ",
+			       "--xid ", xid_string,
+			       NULL);
+	app_info = g_app_info_create_from_commandline (cmdline, NULL, 0, NULL);
+	g_app_info_launch (app_info, NULL, NULL, NULL);
+
+	g_free (cmdline);
+	g_free (device_identifier);
+	g_free (xid_string);
+	g_clear_object (&app_info);
+}
+
+/* Destroy notification function used from g_object_set_data_full() */
+static void
+menu_item_destroy_notify_cb (gpointer data)
+{
+	GVolume *volume;
+
+	volume = G_VOLUME (data);
+	g_object_unref (volume);
+}
+
+static void
+places_sidebar_populate_popup_cb (GtkPlacesSidebar *sidebar,
+				  GtkMenu          *menu,
+				  GFile            *selected_item,
+				  GVolume          *selected_volume,
+				  gpointer          user_data)
+{
+	NautilusWindow *window = NAUTILUS_WINDOW (user_data);
+	GtkWidget *item;
+	GFile *trash;
+
+	if (selected_item) {
+		trash = g_file_new_for_uri ("trash:///");
+		if (g_file_equal (trash, selected_item)) {
+			eel_gtk_menu_append_separator (menu);
+
+			item = gtk_menu_item_new_with_mnemonic (_("Empty _Trash"));
+			g_signal_connect (item, "activate",
+					  G_CALLBACK (empty_trash_cb), window);
+			gtk_widget_show (item);
+			gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+
+			if (nautilus_trash_monitor_is_empty ())
+				gtk_widget_set_sensitive (item, FALSE);
+		}
+		g_object_unref (trash);
+
+		if (g_file_is_native (selected_item)) {
+			eel_gtk_menu_append_separator (menu);
+
+			item = gtk_menu_item_new_with_mnemonic (_("_Properties"));
+			g_signal_connect (item, "activate",
+					  G_CALLBACK (properties_cb), window);
+			gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+			gtk_widget_show (item);
+		}
+	} else if (selected_volume) {
+		if (should_show_format_command (selected_volume)) {
+			item = gtk_menu_item_new_with_mnemonic (_("_Format…"));
+			g_object_set_data_full (G_OBJECT (item), "nautilus-volume",
+						g_object_ref (selected_volume),
+						menu_item_destroy_notify_cb);
+			g_signal_connect (item, "activate",
+					  G_CALLBACK (format_cb), window);
+			gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+			gtk_widget_show (item);
+		}
+	}
+}
+
 static void
 nautilus_window_set_up_sidebar (NautilusWindow *window)
 {
-	GtkWidget *sidebar;
-
 	window->details->sidebar = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
 	gtk_style_context_add_class (gtk_widget_get_style_context (window->details->sidebar),
 				     GTK_STYLE_CLASS_SIDEBAR);
@@ -543,10 +853,34 @@ nautilus_window_set_up_sidebar (NautilusWindow *window)
 			  G_CALLBACK (side_pane_size_allocate_callback),
 			  window);
 
-	sidebar = nautilus_places_sidebar_new (window);
-	gtk_box_pack_start (GTK_BOX (window->details->sidebar), sidebar, TRUE, TRUE, 0);
-	gtk_widget_show (sidebar);
-	gtk_widget_show (GTK_WIDGET (window->details->sidebar));
+	window->details->places_sidebar = gtk_places_sidebar_new ();
+	gtk_places_sidebar_set_open_flags (GTK_PLACES_SIDEBAR (window->details->places_sidebar),
+					   (GTK_PLACES_OPEN_NORMAL
+					    | GTK_PLACES_OPEN_NEW_TAB
+					    | GTK_PLACES_OPEN_NEW_WINDOW));
+	gtk_places_sidebar_set_show_connect_to_server (GTK_PLACES_SIDEBAR (window->details->places_sidebar), TRUE);
+
+	g_signal_connect (window->details->places_sidebar, "open-location",
+			  G_CALLBACK (places_sidebar_open_location_cb), window);
+	g_signal_connect (window->details->places_sidebar, "show-error-message",
+			  G_CALLBACK (places_sidebar_show_error_message_cb), window);
+	g_signal_connect (window->details->places_sidebar, "show-connect-to-server",
+			  G_CALLBACK (places_sidebar_show_connect_to_server_cb), window);
+	g_signal_connect (window->details->places_sidebar, "drag-action-requested",
+			  G_CALLBACK (places_sidebar_drag_action_requested_cb), window);
+	g_signal_connect (window->details->places_sidebar, "drag-action-ask",
+			  G_CALLBACK (places_sidebar_drag_action_ask_cb), window);
+	g_signal_connect (window->details->places_sidebar, "drag-perform-drop",
+			  G_CALLBACK (places_sidebar_drag_perform_drop_cb), window);
+	g_signal_connect (window->details->places_sidebar, "populate-popup",
+			  G_CALLBACK (places_sidebar_populate_popup_cb), window);
+
+	g_signal_connect (window, "loading-uri",
+			  G_CALLBACK (window_loading_uri_cb), window);
+
+	gtk_box_pack_start (GTK_BOX (window->details->sidebar), window->details->places_sidebar, TRUE, TRUE, 0);
+	gtk_widget_show (window->details->places_sidebar);
+	gtk_widget_show (window->details->sidebar);
 }
 
 static void
@@ -557,6 +891,7 @@ nautilus_window_tear_down_sidebar (NautilusWindow *window)
 	if (window->details->sidebar != NULL) {
 		gtk_widget_destroy (GTK_WIDGET (window->details->sidebar));
 		window->details->sidebar = NULL;
+		window->details->places_sidebar = NULL;
 	}
 }
 
